@@ -28,6 +28,12 @@ post_load_eta <- function(ds, input, sys, occ) {
   if (missing(occ)) occ <- ""
   ID <- DVID <- VARIABLE <- NULL
   keys <- c("ID")
+  if (inherits(ds$ID,"factor") & !inherits(input$ID,"factor")) {
+    input[, ID := factor(ID, levels = levels(ID))]
+  }
+  if (!inherits(ds$ID, "factor") & inherits(input$ID, "factor")) {
+    ds[, ID := factor(ID, levels = levels(ID))]
+  }
   if (occ != "") keys <- c(keys, if (length(occ) == 1) "OCC" else sprintf("OCC%s", seq_along(occ)))
   ds <- try(
     merge(
@@ -74,16 +80,24 @@ post_load <- function(dxs, input, sys, dplot, occ) {
   if (sys %in% c("mlx", "mlx18")) {
     keys <- c("ID", "TIME")
     if (occ != "") keys <- c(keys, if (length(occ) == 1) "OCC" else sprintf("OCC%s", seq_along(occ)))
+    
+    if (!is.null(dxs[["predictions"]]) & !is.null(dxs[["sim_blq_npde_iwres"]]) & !is.null(dxs[["sim_blq_y"]])) {
+      dxs[["sim_blq"]] <- merge(dxs[["sim_blq_npde_iwres"]], dxs[["sim_blq_y"]], by = keys)
+      dxs[["sim_blq"]] <- merge(dxs[["sim_blq"]], input, by = keys)
+      dxs[["sim_blq"]] <- merge(dxs[["sim_blq"]], dxs[["predictions"]], by = keys)
+    }
+    
     if (!is.null(dxs[["predictions"]])) {
       dxs[["predictions"]] <- merge(dxs[["predictions"]], input, by = keys)
     }
+    
     if (!is.null(dxs[["finegrid"]])) {
       dxs[["finegrid"]] <- input_finegrid(input, dxs[["finegrid"]])
       dxs[["IND"]] <- dxs[["finegrid"]]
     }
     if (is.null(dxs[["finegrid"]]) && !is.null(dxs[["predictions"]])) {
       warn <-
-        "NO FINEGRID FILE: 
+        "NO FINEGRID FILE:
         we will use instead predictions.txt for individual plots"
       warns$MISSING_FINEGRID <- warn
 
